@@ -62,6 +62,15 @@ class EnergyParameters(seamm.Parameters):
     """
 
     parameters = {
+        "primitive cell": {
+            "default": "Yes",
+            "kind": "boolean",
+            "default_units": "",
+            "enumeration": ("Yes", "No"),
+            "format_string": "",
+            "description": "Use primitive cell:",
+            "help_text": "Whether to use the primitive cell for the calculation.",
+        },
         "SCC": {
             "default": "Yes",
             "kind": "string",
@@ -96,6 +105,27 @@ class EnergyParameters(seamm.Parameters):
                 "steps, the program stops unless requested elsewhere."
             ),
         },
+        "ShellResolvedSCC": {
+            "default": "no",
+            "kind": "string",
+            "default_units": "",
+            "enumeration": ("yes", "no"),
+            "format_string": "",
+            "description": "Shell-resolved charges:",
+            "help_text": (
+                "Whether to use shell-resolved charges. If the parameter set does not "
+                "support this, it will be ignored."
+            ),
+        },
+        "use atom charges": {
+            "default": "yes",
+            "kind": "string",
+            "default_units": "",
+            "enumeration": ("yes", "no"),
+            "format_string": "",
+            "description": "Use existing atomic charges:",
+            "help_text": "Whether to use existing charges on the atoms.",
+        },
         "ThirdOrder": {
             "default": "Default for parameters",
             "kind": "string",
@@ -201,6 +231,45 @@ class EnergyParameters(seamm.Parameters):
             "description": "K-spacing:",
             "help_text": "The spacing of the grid in reciprocal space.",
         },
+        "SpinPolarisation": {
+            "default": "none",
+            "kind": "string",
+            "default_units": "",
+            "enumeration": ("none", "collinear", "noncollinear"),
+            "format_string": "",
+            "description": "Spin polarization:",
+            "help_text": "How to handle spin polarization",
+        },
+        "RelaxTotalSpin": {
+            "default": "yes",
+            "kind": "string",
+            "default_units": "",
+            "enumeration": ("no", "yes"),
+            "format_string": "",
+            "description": "Optimize the spin:",
+            "help_text": "Whether to optimize the spin polarization or leave it fixed.",
+        },
+        "ShellResolvedSpin": {
+            "default": "yes",
+            "kind": "string",
+            "default_units": "",
+            "enumeration": ("yes", "no"),
+            "format_string": "",
+            "description": "Shell-resolved spins:",
+            "help_text": (
+                "Whether to use shell-resolved spin. If the parameter set does not "
+                "support this, it will be ignored."
+            ),
+        },
+        "use atom spins": {
+            "default": "yes",
+            "kind": "string",
+            "default_units": "",
+            "enumeration": ("yes", "no"),
+            "format_string": "",
+            "description": "Use existing atomic spins:",
+            "help_text": "Whether to use existing spins on the atoms.",
+        },
     }
 
     def __init__(self, defaults={}, data=None):
